/*
Copyright (c) Daybrush
name: react-keycon
license: MIT
author: Daybrush
repository: https://github.com/daybrush/keycon
version: 0.1.0
*/
'use strict';

var react = require('@cfcs/react');
var core = require('@cfcs/core');
var KeyController = require('keycon');

function useKeycon(props) {
  return react.useReactive({
    state: {
      isKeydown: false
    },
    mounted: function () {
      var _a, _b;

      var keycon = new KeyController((_b = (_a = props.ref) === null || _a === void 0 ? void 0 : _a.current) !== null && _b !== void 0 ? _b : window);
      var isKeydown = core.observe(false);
      keycon.keydown(props.keys, function () {
        isKeydown.current = true;
      });
      keycon.keyup(props.keys, function () {
        isKeydown.current = false;
      });
      return core.reactive({
        inst: keycon,
        destroy: function () {
          return keycon.destroy();
        },
        isKeydown: isKeydown
      });
    },
    destroy: function (inst) {
      inst.destroy();
    },
    events: ["keydown", "keyup", "blur"],
    on: function (inst, name, callback) {
      var keycon = inst.inst;

      if (name === "keydown") {
        keycon.keydown(props.keys, callback);
      } else if (name === "keyup") {
        keycon.keyup(props.keys, callback);
      } else {
        keycon.on(name, callback);
      }
    },
    off: function (inst, name, callback) {
      var keycon = inst.inst;

      if (name === "keydown") {
        keycon.offKeydown(props.keys, callback);
      } else if (name === "keyup") {
        keycon.offKeyup(props.keys, callback);
      } else {
        keycon.off(name, callback);
      }
    }
  });
}

exports.useKeycon = useKeycon;
//# sourceMappingURL=keycon.cjs.js.map
